@@ -22,6 +22,9 @@ pub const FIRST_USER_TOKEN: TerminalIndex = 5;
 
 const EOI_TOKEN: &str = "$";
 
+///
+/// The Token<'t> type represents a scanned token.
+/// It has a reference to the scanned text in the symbol member.
 ///
 /// The lifetime parameter `'t` refers to the lifetime of the scanned text.
 ///
@@ -29,18 +32,26 @@ const EOI_TOKEN: &str = "$";
 pub struct Token<'t> {
     /// The matched string
     pub symbol: &'t str,
+
     /// The index of the terminal in the augmented terminal list
     pub token_type: TerminalIndex,
+
     /// Position information: line number, starting by 1
     /// A value of 0 indicates an invalid position, for instance for EOF token.
     pub line: usize,
+
     /// Position information: column number, starting by 1
     /// A value of 0 indicates an invalid position, for instance for EOF token.
     pub column: usize,
+
     /// Length of the matched input terminal
     /// A value of 0 indicates a virtual token, for instance an EOF token.
     /// Be careful: User tokens with length 0 are always invalid!!!
     pub length: usize,
+
+    /// Relative position from start position as byte offset after matching this
+    /// terminal. Needed for scanner switching.
+    pub(crate) pos: usize,
 }
 
 impl<'t> Token<'t> {
@@ -54,6 +65,7 @@ impl<'t> Token<'t> {
             line: 0,
             column: 0,
             length: 0,
+            pos: 0,
         }
     }
 
@@ -66,6 +78,7 @@ impl<'t> Token<'t> {
         line: usize,
         column: usize,
         length: usize,
+        pos: usize,
     ) -> Self {
         Self {
             symbol,
@@ -73,6 +86,7 @@ impl<'t> Token<'t> {
             line,
             column,
             length,
+            pos,
         }
     }
 
