@@ -13,3 +13,8 @@ pub mod lexer;
 /// Module that provides types for syntactical analysis.
 ///
 pub mod parser;
+
+///
+/// error_chain's error module that auto-creates basic error types.
+///
+pub mod errors;
