@@ -15,31 +15,36 @@ pub type ProductionIndex = usize;
 ///
 pub type NonTerminalIndex = usize;
 
+///
+/// The index of a scanner configuration
+///
+pub type ScannerIndex = usize;
+
 ///
 /// Module with types used to handle the parse tree that is build during runs of
 /// the generated parsers.
 ///
 #[forbid(missing_docs)]
-pub mod ast;
-pub use ast::ParseTreeType;
+pub mod parse_tree_type;
+pub use parse_tree_type::ParseTreeType;
 
 ///
-/// Module with types used in the generated parser's ast stack.
+/// Module with types used in the generated parser's parse tree stack.
 ///
 #[forbid(missing_docs)]
 pub mod parse_tree_stack_entry;
 pub use parse_tree_stack_entry::ParseTreeStackEntry;
 
 ///
-/// Module with types used predict the next productions to choose during runs of
-/// generated parsers.
+/// Module with types used to predict the next productions to choose during runs
+/// of generated parsers.
 ///
 #[forbid(missing_docs)]
 pub mod lookahead_dfa;
 pub use lookahead_dfa::{DFAState, DFATransition, LookaheadDFA};
 
 ///
-/// Module with types used in the parser stack.
+/// Module with types used in the parse stack.
 ///
 #[forbid(missing_docs)]
 pub mod parse_type;
@@ -56,10 +61,5 @@ pub use parser_types::{LLKParser, Production};
 /// Module with the UserActionsTrait type.
 ///
 #[forbid(missing_docs)]
-pub mod user_actions;
-pub use user_actions::UserActionsTrait;
-
-///
-/// error_chains error module that auto-creates basic error types.
-///
-pub mod errors;
+pub mod user_access;
+pub use user_access::UserActionsTrait;
