@@ -1,5 +1,5 @@
 use crate::lexer::TerminalIndex;
-use crate::parser::{NonTerminalIndex, ProductionIndex};
+use crate::parser::{NonTerminalIndex, ProductionIndex, ScannerIndex};
 use std::fmt::{Display, Error, Formatter};
 
 ///
@@ -17,6 +17,11 @@ pub enum ParseType {
     ///
     T(TerminalIndex),
 
+    ///
+    /// The index of a scanner configuration
+    ///
+    S(ScannerIndex),
+
     ///
     /// End of production marker
     ///
@@ -28,6 +33,7 @@ impl Display for ParseType {
         match self {
             Self::N(n) => write!(f, "N({})", n),
             Self::T(t) => write!(f, "T({})", t),
+            Self::S(s) => write!(f, "S({})", s),
             Self::E(e) => write!(f, "E({})", e),
         }
     }
@@ -35,7 +41,7 @@ impl Display for ParseType {
 
 ///
 /// The generated parsers are push down automata (PDA) which utilize a stack
-/// during parsing and helps processing of the grammar's productions.
+/// during parsing. It helps to process the grammar's productions.
 ///
 pub struct ParseStack {
     ///
