@@ -1,4 +1,4 @@
-use super::errors::*;
+use crate::errors::*;
 use crate::lexer::TokenStream;
 use crate::parser::{
     LookaheadDFA, NonTerminalIndex, ParseStack, ParseTreeStackEntry, ParseTreeType, ParseType,
@@ -41,6 +41,7 @@ impl Production {
             .map(|s| match s {
                 ParseType::N(n) => non_terminal_names[*n].to_owned(),
                 ParseType::T(t) => format!(r#""{}""#, terminal_names[*t]),
+                ParseType::S(s) => format!("%sc({})", s),
                 _ => "?".to_owned(),
             })
             .collect::<Vec<String>>()
@@ -184,13 +185,17 @@ impl<'t> LLKParser {
         );
     }
 
-    fn process_ast_stack(
+    fn process_item_stack(
         &mut self,
         prod_num: ProductionIndex,
         user_actions: &mut dyn UserActionsTrait,
     ) -> Result<()> {
-        let l = self.productions[prod_num].production.len();
-        // We remove the last n entries from the ast stack and insert them as
+        let l = self.productions[prod_num]
+            .production
+            .iter()
+            .filter(|s| !matches!(s, ParseType::S(_)))
+            .count();
+        // We remove the last n entries from the parse tree stack and insert them as
         // children under the node laying below on the stack
         let children = self
             .parse_tree_stack
@@ -219,7 +224,7 @@ impl<'t> LLKParser {
             // The node's id is pushed on the AST stack
             self.parse_tree_stack.push(ParseTreeStackEntry::Id(node_id));
         } else {
-            panic!("Expected node id on ast stack, found {:?}", tos);
+            panic!("Expected node id on parse tree stack, found {:?}", tos);
         }
 
         Ok(())
@@ -247,22 +252,15 @@ impl<'t> LLKParser {
                 ("<<Error>>".to_string(), 0, format!("{}(?)", file_name))
             };
 
-        trace!(
-            r"
-Parser stack:
-{}
-",
-            self.parser_stack
-        );
+        trace!("\nParser stack:\n{}\n", self.parser_stack);
 
         let prod_num = self.current_production().unwrap();
 
         let msg = format!(
-            r#"{} at {}
-Current production is:
-/* {} */ {}
-Lookahead token: {} ({})
-"#,
+            "{} at {}\n\
+            Current production is:\n\
+            /* {} */ {}\n\
+            Lookahead token: {} ({})\n",
             msg,
             location,
             prod_num,
@@ -281,11 +279,11 @@ Lookahead token: {} ({})
     ///
     pub fn parse(
         &mut self,
-        stream: &RefCell<TokenStream<'t>>,
+        stream: RefCell<TokenStream<'t>>,
         user_actions: &mut dyn UserActionsTrait,
     ) -> Result<()> {
         let prod_num = self
-            .predict_production(self.start_symbol_index, stream)
+            .predict_production(self.start_symbol_index, &stream)
             .chain_err(|| {
                 format!(
                     "Can't predict production while trying to start parsing with {}!",
@@ -319,13 +317,13 @@ Lookahead token: {} ({})
                                     self.terminal_names[t], token
                                 )
                                 .as_str(),
-                                stream,
+                                &stream,
                             );
                             return Err(msg.into());
                         }
                     }
                     ParseType::N(n) => {
-                        let prod_num = self.predict_production(n, stream).chain_err(|| {
+                        let prod_num = self.predict_production(n, &stream).chain_err(|| {
                             let nt_name = self.non_terminal_names[n];
                             self.diagnostic_message(
                                 format!(
@@ -335,24 +333,28 @@ Lookahead token: {} ({})
                                     nt_name,
                                 )
                                 .as_str(),
-                                stream,
+                                &stream,
                             )
                         })?;
                         self.parser_stack.stack.pop();
                         self.push_production(prod_num);
                     }
+                    ParseType::S(s) => {
+                        stream.borrow_mut().switch_scanner(s)?;
+                        self.parser_stack.stack.pop();
+                    }
                     ParseType::E(p) => {
                         self.production_depth -= 1;
                         debug!("Popped production {} -> depth {}", p, self.production_depth);
                         self.parser_stack.stack.pop(); // Pop the End of production marker
-                        self.process_ast_stack(p, user_actions)?;
+                        self.process_item_stack(p, user_actions)?;
                     }
                 }
             }
         }
 
         if !stream.borrow().all_input_consumed() {
-            Err(self.diagnostic_message("Unprocessed input", stream).into())
+            Err(self.diagnostic_message("Unprocessed input", &stream).into())
         } else {
             Ok(())
         }
